"""
    Elastic Email REST API

    This API is based on the REST API architecture, allowing the user to easily manage their data with this resource-based approach.    Every API call is established on which specific request type (GET, POST, PUT, DELETE) will be used.    To start using this API, you will need your Access Token (available <a href=\"https://elasticemail.com/account#/settings/new/manage-api\">here</a>). Remember to keep it safe. Required access levels are listed in the given request’s description.    This is the documentation for REST API. If you’d like to read our legacy documentation regarding Web API v2 click <a href=\"https://api.elasticemail.com/public/help\">here</a>.  # noqa: E501

    The version of the OpenAPI document: 4.0.0
    Contact: support@elasticemail.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import ElasticEmail
from ElasticEmail.api.sub_accounts_api import SubAccountsApi  # noqa: E501


class TestSubAccountsApi(unittest.TestCase):
    """SubAccountsApi unit test stubs"""

    def setUp(self):
        self.api = SubAccountsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_subaccounts_by_email_credits_patch(self):
        """Test case for subaccounts_by_email_credits_patch

        Add, Subtract Email Credits  # noqa: E501
        """
        pass

    def test_subaccounts_by_email_delete(self):
        """Test case for subaccounts_by_email_delete

        Delete SubAccount  # noqa: E501
        """
        pass

    def test_subaccounts_by_email_get(self):
        """Test case for subaccounts_by_email_get

        Load SubAccount  # noqa: E501
        """
        pass

    def test_subaccounts_by_email_settings_email_put(self):
        """Test case for subaccounts_by_email_settings_email_put

        Update SubAccount Email Settings  # noqa: E501
        """
        pass

    def test_subaccounts_get(self):
        """Test case for subaccounts_get

        Load SubAccounts  # noqa: E501
        """
        pass

    def test_subaccounts_post(self):
        """Test case for subaccounts_post

        Add SubAccount  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
